pub struct ReconciliationRegistration {Show 18 fields
pub credit_registration_id: Uuid,
pub user_id: Uuid,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub email: Option<String>,
pub student_number: Option<String>,
pub course_id: Uuid,
pub course_name: String,
pub course_module_id: Uuid,
pub course_module_name: Option<String>,
pub uh_course_code: Option<String>,
pub state: CreditRegistrationState,
pub state_entered_at: DateTime<Utc>,
pub submitted_at: Option<DateTime<Utc>>,
pub submitted_attainment_id: Option<String>,
pub sisu_attainment_id: Option<String>,
pub registered_at: Option<DateTime<Utc>>,
pub terminal_at: Option<DateTime<Utc>>,
}Expand description
One ledger row, flattened to what every reconciliation list needs to name a student and link onwards.
Fields
credit_registration_id: Uuiduser_id: Uuidfirst_name: Option<String>last_name: Option<String>email: Option<String>student_number: Option<String>course_id: Uuidcourse_name: Stringcourse_module_id: Uuidcourse_module_name: Option<String>uh_course_code: Option<String>state: CreditRegistrationStatestate_entered_at: DateTime<Utc>submitted_at: Option<DateTime<Utc>>submitted_attainment_id: Option<String>sisu_attainment_id: Option<String>registered_at: Option<DateTime<Utc>>terminal_at: Option<DateTime<Utc>>Trait Implementations
Sourceimpl Clone for ReconciliationRegistration
impl Clone for ReconciliationRegistration
Sourcefn clone(&self) -> ReconciliationRegistration
fn clone(&self) -> ReconciliationRegistration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ReconciliationRegistration
impl ComposeSchema for ReconciliationRegistration
Sourceimpl Debug for ReconciliationRegistration
impl Debug for ReconciliationRegistration
Sourceimpl<'de> Deserialize<'de> for ReconciliationRegistration
impl<'de> Deserialize<'de> for ReconciliationRegistration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for ReconciliationRegistration
impl ToSchema for ReconciliationRegistration
impl StructuralPartialEq for ReconciliationRegistration